# ALIA

This is a collection of random helper functions to make coding in Python easier.

---

### [tools.py](https://github.com/aliavictor/alia/blob/main/alia/tools.py)

Miscellaneous helper functions ranging from string formatting to file parsing.

### [df_tools.py](https://github.com/aliavictor/alia/blob/main/alia/df_tools.py)

Helper functions made specifically for handling `pandas` dataframes.

### [colors.py](https://github.com/aliavictor/alia/blob/main/alia/colors.py)

Color printing functions for stylized printing.
